==> sensei-image-api-1.0.2.tgz: package/src/modules/ix.js <==
const superagent = require('superagent');
const fs = require('fs');
const sharp = require('sharp');

module.exports = async (req, res) => {
    if (!req.query.url) {
        res.setHeader('Content-Type', 'application/json');
        res.send(JSON.stringify({
            error: 'URL is required!'
        }))
        return;
    }
    let url = req.query.url;
    if (!url.includes('http') && !url.includes('.')) {
        res.send(JSON.stringify({
            error: 'A valid URL must be provided!'
        }))
        return;
    }

    if ((!url.toLowerCase().includes('.png')) && (!url.toLowerCase().includes('.gif')) && (!url.toLowerCase().includes('.jpg')) && (!url.toLowerCase().includes('.jpeg'))) return res.send(JSON.stringify({
        error: 'This is not a valid image!'
    }))

    function notch(type) {
        sharp(image.body)
            .overlayWith(type)
            .toBuffer((err, data, info) => {
                if (err) {
                    res.setHeader('Content-Type', 'application/json');
                    res.send(`{"error":"Something happened. Try again later!"}`);
                    return;
                }
                res.setHeader('Content-Type', 'image/png'); res.end(data)
            });
    }

    let image = await superagent.get(req.query.url).catch(err => { if (err) return res.send(JSON.stringify({ error: 'Failed receiving the image. Check the URL and make sure the image is valid.' })) });
    let img = await sharp(image.body).metadata();
    let portrait = await sharp('./images/iphone.png').toBuffer();
    let landscape = await sharp('./images/iphoneLandscape.png').toBuffer();

    if (img.width === 1125 && img.height === 2436) {
        notch(portrait)
    } else if (img.width === 2436 && img.height === 1125) {
        notch(landscape)
    } else {
        res.setHeader('Content-Type', 'application/json');
        res.send(`{"error":"This is not an iPhone X screenshot | it doesn't have an iPhone X resolution!"}`)
    }
};

==> sensei-image-api-1.1.0.tgz: package/src/modules/ix.js <==
const superagent = require('superagent');
const fs = require('fs');
const sharp = require('sharp');

module.exports = async (req, res) => {
    if (!req.query.url) {
        res.setHeader('Content-Type', 'application/json');
        res.send(JSON.stringify({
            error: 'URL is required!'
        }))
        return;
    }
    let url = req.query.url;
    if (!url.includes('http') && !url.includes('.')) {
        res.send(JSON.stringify({
            error: 'A valid URL must be provided!'
        }))
        return;
    }

    if ((!url.toLowerCase().includes('.png')) && (!url.toLowerCase().includes('.gif')) && (!url.toLowerCase().includes('.jpg')) && (!url.toLowerCase().includes('.jpeg'))) return res.send(JSON.stringify({
        error: 'This is not a valid image!'
    }))

    function notch(type) {
        sharp(image.body)
            .overlayWith(type)
            .toBuffer((err, data, info) => {
                if (err) {
                    res.setHeader('Content-Type', 'application/json');
                    res.send(`{"error":"Something happened. Try again later!"}`);
                    return;
                }
                res.setHeader('Content-Type', 'image/png'); res.end(data)
            });
    }

    let image = await superagent.get(req.query.url).catch(err => { if (err) return res.send(JSON.stringify({ error: 'Failed receiving the image. Check the URL and make sure the image is valid.' })) });
    let img = await sharp(image.body).metadata();
    let portrait = await sharp(__dirname + '/images/iphone.png').toBuffer();
    let landscape = await sharp(__dirname + '/images/iphoneLandscape.png').toBuffer();

    if (img.width === 1125 && img.height === 2436) {
        notch(portrait)
    } else if (img.width === 2436 && img.height === 1125) {
        notch(landscape)
    } else {
        res.setHeader('Content-Type', 'application/json');
        res.send(`{"error":"This is not an iPhone X screenshot | it doesn't have an iPhone X resolution!"}`)
    }
};
